==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/RelativeStrengthIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RelativeStrengthIndexIndicatorStrategy } from "./RelativeStrengthIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var RelativeStrengthIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RelativeStrengthIndexIndicator, _super);
    function RelativeStrengthIndexIndicator() {
        return _super.call(this) || this;
    }
    RelativeStrengthIndexIndicator.prototype.get_x5 = function () {
        return 1;
    };
    RelativeStrengthIndexIndicator.prototype.get_yy = function () {
        return new RelativeStrengthIndexIndicatorStrategy();
    };
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    RelativeStrengthIndexIndicator.prototype.get_zb = function () {
        return RelativeStrengthIndexIndicator.$;
    };
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "zj", {
        get: function () {
            return typeGetValue(this.c(RelativeStrengthIndexIndicator.zk));
        },
        set: function (a) {
            this.h(RelativeStrengthIndexIndicator.zk, a);
        },
        enumerable: false,
        configurable: true
    });
    RelativeStrengthIndexIndicator.prototype.y4 = function () {
        return this.zj;
    };
    RelativeStrengthIndexIndicator.prototype.zd = function (a) {
        this.zj = a;
    };
    RelativeStrengthIndexIndicator.$t = markType(RelativeStrengthIndexIndicator, 'RelativeStrengthIndexIndicator', StrategyBasedIndicator.$);
    RelativeStrengthIndexIndicator.zk = StrategyBasedIndicator.zg(14, RelativeStrengthIndexIndicator.$);
    return RelativeStrengthIndexIndicator;
}(StrategyBasedIndicator));
export { RelativeStrengthIndexIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/RelativeStrengthIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RelativeStrengthIndexIndicatorStrategy } from "./RelativeStrengthIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var RelativeStrengthIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RelativeStrengthIndexIndicator, _super);
    function RelativeStrengthIndexIndicator() {
        return _super.call(this) || this;
    }
    RelativeStrengthIndexIndicator.prototype.bj = function () {
        return new RelativeStrengthIndexIndicator();
    };
    RelativeStrengthIndexIndicator.prototype.get_aax = function () {
        return 1;
    };
    RelativeStrengthIndexIndicator.prototype.get_abq = function () {
        return new RelativeStrengthIndexIndicatorStrategy();
    };
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "abq", {
        get: function () {
            return this.get_abq();
        },
        enumerable: false,
        configurable: true
    });
    RelativeStrengthIndexIndicator.prototype.get_ab3 = function () {
        return RelativeStrengthIndexIndicator.$;
    };
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "acb", {
        get: function () {
            return typeGetValue(this.c(RelativeStrengthIndexIndicator.acc));
        },
        set: function (a) {
            this.h(RelativeStrengthIndexIndicator.acc, a);
        },
        enumerable: false,
        configurable: true
    });
    RelativeStrengthIndexIndicator.prototype.abw = function () {
        return this.acb;
    };
    RelativeStrengthIndexIndicator.prototype.ab5 = function (a) {
        this.acb = a;
    };
    RelativeStrengthIndexIndicator.$t = markType(RelativeStrengthIndexIndicator, 'RelativeStrengthIndexIndicator', StrategyBasedIndicator.$);
    RelativeStrengthIndexIndicator.acc = StrategyBasedIndicator.ab8(14, RelativeStrengthIndexIndicator.$);
    return RelativeStrengthIndexIndicator;
}(StrategyBasedIndicator));
export { RelativeStrengthIndexIndicator };
